@@ -16,8 +16,6 @@
 #' \itemize{
 #'  \item{"industry_jobs"}{ Payroll jobs by industry division, state, sex, and age
 #'  group (Table 4)}
-#'  \item{"industry_wages"}{ Total wages by industry division, state, sex, and age
-#'  group (Table 4)}
 #'  \item{"sa4_jobs"}{ Payroll jobs by statistical area 4 (SA4) and state (Table 5)}
 #'  \item{"sa3_jobs}{ Payroll jobs by statistical area 4 (SA4), statistical
 #'  area 3 (SA3), and state (Table 5)}
@@ -49,7 +47,6 @@
 
 read_payrolls <- function(series = c(
                             "industry_jobs",
-                            "industry_wages",
                             "sa4_jobs",
                             "sa3_jobs",
                             "subindustry_jobs",
@@ -64,7 +61,6 @@ read_payrolls <- function(series = c(
 
   cube_name <- switch(series,
     "industry_jobs" = "DO004",
-    "industry_wages" = "DO004",
     "sa4_jobs" = "DO005",
     "sa3_jobs" = "DO005",
     "subindustry_jobs" = "DO006",
@@ -101,7 +97,6 @@ read_payrolls <- function(series = c(
 
   sheet_name <- switch(series,
     "industry_jobs" = "Payroll jobs index",
-    "industry_wages" = "Total wages index",
     "sa4_jobs" = "Payroll jobs index-SA4",
     "sa3_jobs" = "Payroll jobs index-SA3",
     "subindustry_jobs" = "Payroll jobs index-Subdivision",
